@@ -71,6 +71,7 @@ class Viewer(QtGui.QMainWindow):
         self.low_hu = -1024
        
         self.pix_label = TrackingLabel(self)
+        self.pix_label.setCursor(QtCore.Qt.CrossCursor)
         self.color_table = [QtGui.qRgb(i, i, i) for i in range(256)]
 
         scroll_area = QtGui.QScrollArea()
@@ -92,9 +93,10 @@ class Viewer(QtGui.QMainWindow):
         self.x_label = QtGui.QLabel("")
         self.y_label = QtGui.QLabel("")
         self.z_label = QtGui.QLabel("")
+        self.use_fractional_coordinates = True
         self.ij_label = QtGui.QLabel("")
 
-        self._zoom = 4
+        self._zoom = 1
         self.mouse_x = -1
         self.mouse_y = -1
        
@@ -130,9 +132,29 @@ class Viewer(QtGui.QMainWindow):
         self.view_menu = QtGui.QMenu('&View', self)
         self.view_menu.addAction('Zoom In', self.increase_zoom, QtCore.Qt.CTRL + QtCore.Qt.Key_Plus)
         self.view_menu.addAction('Zoom Out', self.decrease_zoom, QtCore.Qt.CTRL + QtCore.Qt.Key_Minus)
+        fullscreen = QtGui.QAction('&Full Screen', self)
+        fullscreen.setCheckable(True)
+        fullscreen.setShortcut(QtCore.Qt.Key_F11)
+        fullscreen.toggled.connect(self.toggle_full_screen)
+        self.view_menu.addAction(fullscreen)
+
+        self.tools_menu = QtGui.QMenu("&Tools", self)
+        self.tools_menu.addAction('&Show DICOM structure', self.show_structure, QtCore.Qt.Key_F2)
 
         self.menuBar().addMenu(self.file_menu)
         self.menuBar().addMenu(self.view_menu)
+        self.menuBar().addMenu(self.tools_menu)
+
+    def show_structure(self):
+        if self.file_name:
+            f = dicom.read_file(self.file_name)
+            print str(f)
+
+    def toggle_full_screen(self, toggled):
+        if toggled:
+            self.setWindowState(QtCore.Qt.WindowFullScreen)
+        else:
+            self.setWindowState(QtCore.Qt.WindowNoState)
 
     def on_file_item_change(self):
         if not len(self.file_list.selectedItems()):
@@ -191,12 +213,16 @@ class Viewer(QtGui.QMainWindow):
     @property
     def mouse_ij(self):
         '''Mouse position as voxel index in current DICOM slice.'''
-        return self.mouse_x // self.zoom, self.mouse_y // self.zoom
+        return self.mouse_y // self.zoom, self.mouse_x // self.zoom
 
     @property
     def mouse_xyz(self):
         '''Mouse position in DICOM coordinates.'''
-        return self.get_coordinates(*self.mouse_ij)
+        if self.use_fractional_coordinates:
+            correction = (self.zoom - 1.) / (2. * self.zoom) # To get center of left top pixel in a zoom grid
+            return self.get_coordinates(self.mouse_x / self.zoom - correction, self.mouse_y / self.zoom - correction)
+        else:
+            return self.get_coordinates(self.mouse_x // self.zoom, self.mouse_y // self.zoom)
 
     def update_coordinates(self):
         if self.file:
@@ -206,8 +232,8 @@ class Viewer(QtGui.QMainWindow):
             if i >= 0 and j >= 0 and i < self.data.shape[0] and j < self.data.shape[1]:
                 self.x_label.setText("x: %.2f" % x)
                 self.y_label.setText("y: %.2f" % y)
-                self.ij_label.setText("Pos: (%d,%d)" % self.mouse_ij)
-                self.hu_label.setText("HU: %d" % int(self.data[j, i]))
+                self.ij_label.setText("Pos: (%d, %d)" % self.mouse_ij)
+                self.hu_label.setText("HU: %d" % int(self.data[i, j]))
                 return
             else:
                 self.hu_label.setText("HU: ???")     
